[![PyPI](https://img.shields.io/pypi/v/heliq?label=PyPI)](https://pypi.org/project/heliq/)
[![Read the Docs (version)](https://img.shields.io/readthedocs/heliq/stable?label=Docs)](https://heliq.readthedocs.io/en/stable/?badge=stable)
![Tests](https://img.shields.io/github/workflow/status/wohe157/heliq/Test?label=Tests)

HeliQ
=====

Quantification of helical morphologies

* Home: [github.com/wohe157/heliq](https://github.com/wohe157/heliq)
* Documentation: [heliq.readthedocs.io](https://heliq.readthedocs.io/)


Installation
------------

From PyPI:

```shell
pip install heliq
```

Citation
--------
W. Heyvaert, A. Pedrazo-Tardajos, A. Kadu, N. Claes, G. González-Rubio, L. M. Liz-Marzán, W. Albrecht, S. Bals, *HeliQ*. **2022**.
